@@ -32,7 +32,7 @@ typedef struct _ManualClient ManualClient;
 
 struct _ManualClient
 {
-  int    priority;
+  int    order;
   int    argc;
   char **argv;
 };
@@ -50,14 +50,14 @@ client_free (ManualClient *client)
   g_free (client);
 }
 
-/* Compare client records by priority */
+/* Compare client records by order */
 static gint
 client_compare (gconstpointer a, gconstpointer b)
 {
   const ManualClient *client_a = a;
   const ManualClient *client_b = b;
   
-  return client_a->priority - client_b->priority;
+  return client_a->order - client_b->order;
 }
 
 /* Read in the client record for a given session */
@@ -99,7 +99,7 @@ startup_list_read (gchar *name)
 	    }
 
 	  if (strcmp (p+1, "Priority") == 0)
-	    current->priority = atoi (value);
+	    current->order = atoi (value);
 	  else if (strcmp (p+1, "RestartCommand") == 0)
 	    gnome_config_make_vector (value, &current->argc, &current->argv);
 	}
@@ -143,7 +143,7 @@ startup_list_write (GSList *sl, const gchar *name)
       g_free (key);
 
       key = g_strdup_printf ("%d,%s", i, "Priority");
-      gnome_config_set_int (key, client->priority);
+      gnome_config_set_int (key, client->order);
       g_free (key);
 
       key = g_strdup_printf ("%d,%s", i, "RestartCommand");
@@ -173,7 +173,7 @@ startup_list_duplicate (GSList *sl)
       ManualClient *client = tmp_list->data;
       ManualClient *new_client = g_new (ManualClient, 1);
 
-      new_client->priority = client->priority;
+      new_client->order = client->order;
       new_client->argc = client->argc;
       new_client->argv = g_new (gchar *, client->argc);
       
@@ -217,17 +217,18 @@ startup_list_update_gui (GSList *sl, GtkTreeModel *model, GtkTreeSelection *sel)
 
   tmp_list = sl;
   while (tmp_list) {
-    gchar *pri, *name;
     ManualClient *client = tmp_list->data;
+    char         *order;
+    char         *name;
 
-    pri = g_strdup_printf ("%d", client->priority);
+    order = g_strdup_printf ("%d", client->order);
     name = gnome_config_assemble_vector (client->argc,
-					    (const char * const *)client->argv);
+					 (const char * const *)client->argv);
 
     gtk_list_store_append (GTK_LIST_STORE (model), &iter);
-    gtk_list_store_set (GTK_LIST_STORE (model), &iter, 0, client, 1, pri, 2, name, -1);
+    gtk_list_store_set (GTK_LIST_STORE (model), &iter, 0, client, 1, order, 2, name, -1);
 
-    g_free (pri);
+    g_free (order);
     g_free (name);
 
     tmp_list = tmp_list->next;
@@ -250,7 +251,7 @@ is_blank (const gchar *str)
  * is used to implement hiding the dialog when the user switches
  * away to another page of the control center */
 static gboolean
-edit_client (gchar *title, ManualClient *client, GtkWidget **dialog)
+edit_client (gchar *title, ManualClient *client, GtkWidget **dialog, GtkWidget *parent_dlg)
 {
   GtkWidget *entry;
   GtkWidget *spinbutton;
@@ -265,19 +266,20 @@ edit_client (gchar *title, ManualClient *client, GtkWidget **dialog)
 
   gchar *tmp;
 
-  *dialog = gnome_dialog_new (title,
-			     GNOME_STOCK_BUTTON_CANCEL,
-			     GNOME_STOCK_BUTTON_OK,
-			     NULL);
+  *dialog = gtk_dialog_new_with_buttons (title,
+					 GTK_WINDOW (parent_dlg),
+					 GTK_DIALOG_MODAL,
+					 GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+					 GTK_STOCK_OK, GTK_RESPONSE_OK,
+					 NULL);
 
-  gnome_dialog_close_hides (GNOME_DIALOG (*dialog), TRUE);
-  gtk_window_set_policy (GTK_WINDOW (*dialog), FALSE, TRUE, FALSE);
   gtk_window_set_default_size (GTK_WINDOW (*dialog), 400, -1);
-  
+ 
+  gtk_window_set_transient_for (GTK_WINDOW (*dialog), GTK_WINDOW (parent_dlg));
   vbox = gtk_vbox_new (FALSE, GNOME_PAD_SMALL);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), GNOME_PAD_SMALL);
   
-  gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (*dialog)->vbox), vbox,
+  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (*dialog)->vbox), vbox,
 		      TRUE, TRUE, 0);
 
   hbox = gtk_hbox_new (FALSE, GNOME_PAD_SMALL);
@@ -304,7 +306,7 @@ edit_client (gchar *title, ManualClient *client, GtkWidget **dialog)
   hbox = gtk_hbox_new (FALSE, GNOME_PAD_SMALL);
   a = gtk_alignment_new (0.0, 0.5, 0.0, 0.0);
   gtk_box_pack_start (GTK_BOX (hbox), a, FALSE, FALSE, 0);
-  label = gtk_label_new_with_mnemonic (_("_Priority:"));
+  label = gtk_label_new_with_mnemonic (_("_Order:"));
   gtk_container_add (GTK_CONTAINER (a), label);
 
   gtk_container_set_border_width (GTK_CONTAINER (hbox), GNOME_PAD_SMALL);
@@ -313,16 +315,17 @@ edit_client (gchar *title, ManualClient *client, GtkWidget **dialog)
   alignment = gtk_alignment_new (0.0, 0.5, 0.0, 0.0);
   gtk_box_pack_start (GTK_BOX (hbox), alignment, FALSE, FALSE, 0);
 
-  adjustment = gtk_adjustment_new (client->priority,
+  adjustment = gtk_adjustment_new (client->order,
 				   0.0, 200.0, 1.0, 10.0, 10.0); 
   spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (adjustment), 1.0, 0);
+  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton), TRUE);
   gtk_container_add (GTK_CONTAINER (alignment), spinbutton);
 
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), GTK_WIDGET (spinbutton));
   
   gtk_widget_show_all (vbox);
 
-  while (gnome_dialog_run (GNOME_DIALOG (*dialog)) == 1)
+  while (gtk_dialog_run (GTK_DIALOG (*dialog)) == GTK_RESPONSE_OK)
     {
       const gchar *tmp = gtk_entry_get_text (GTK_ENTRY (entry));
 
@@ -332,13 +335,13 @@ edit_client (gchar *title, ManualClient *client, GtkWidget **dialog)
 	  
 	  gtk_widget_show (*dialog);
 	  
-	  msgbox = gnome_message_box_new (_("The startup command cannot be empty"),
-					  GNOME_MESSAGE_BOX_ERROR,
-					  GNOME_STOCK_BUTTON_OK,
-					  NULL);
-	  
-	  gnome_dialog_set_parent (GNOME_DIALOG (msgbox), GTK_WINDOW (*dialog));
-	  gnome_dialog_run (GNOME_DIALOG (msgbox));
+	  msgbox = gtk_message_dialog_new (GTK_WINDOW (parent_dlg),
+					   GTK_DIALOG_MODAL,
+					   GTK_MESSAGE_ERROR,
+					   GTK_BUTTONS_OK,
+					   _("The startup command cannot be empty"));
+	  gtk_dialog_run (GTK_DIALOG (msgbox));
+	  gtk_widget_destroy (msgbox);
 	}
       else
 	{
@@ -349,7 +352,7 @@ edit_client (gchar *title, ManualClient *client, GtkWidget **dialog)
 	  g_free (client->argv);
 	  
 	  gnome_config_make_vector (tmp, &client->argc, &client->argv);
-	  client->priority = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (spinbutton));
+	  client->order = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (spinbutton));
 
 	  gtk_widget_destroy (*dialog);
 	  *dialog = NULL;
@@ -365,14 +368,14 @@ edit_client (gchar *title, ManualClient *client, GtkWidget **dialog)
 
 /* Prompt the user with a dialog for adding a new client */
 void
-startup_list_add_dialog (GSList **sl, GtkWidget **dialog)
+startup_list_add_dialog (GSList **sl, GtkWidget **dialog, GtkWidget *parent_dlg)
 {
   ManualClient *client = g_new (ManualClient, 1);
-  client->priority = 50;
+  client->order = 50;
   client->argc = 0;
   client->argv = NULL;
 
-  if (edit_client (_("Add Startup Program"), client, dialog))
+  if (edit_client (_("Add Startup Program"), client, dialog, parent_dlg))
     {
       *sl = g_slist_prepend (*sl, client);
       *sl = g_slist_sort (*sl, client_compare);
@@ -384,7 +387,7 @@ startup_list_add_dialog (GSList **sl, GtkWidget **dialog)
 
 /* Prompt the user with a dialog for editing the currently selected client */
 void
-startup_list_edit_dialog (GSList **sl, GtkTreeModel *model, GtkTreeSelection *sel, GtkWidget **dialog)
+startup_list_edit_dialog (GSList **sl, GtkTreeModel *model, GtkTreeSelection *sel, GtkWidget **dialog, GtkWidget *parent_dlg)
 {
   ManualClient *client;
   GtkTreeIter iter;
@@ -393,7 +396,7 @@ startup_list_edit_dialog (GSList **sl, GtkTreeModel *model, GtkTreeSelection *se
 
   gtk_tree_model_get (model, &iter, 0, &client, -1);
 
-  if (edit_client (_("Edit Startup Program"), client, dialog)) {
+  if (edit_client (_("Edit Startup Program"), client, dialog, parent_dlg)) {
     *sl = g_slist_sort (*sl, client_compare);
     spc_write_state ();
   }
