@@ -27,6 +27,7 @@ in this Software without prior written authorization from the X Consortium.
 Author:  Ralph Mor, X Consortium
 ******************************************************************************/
 
+#include "config.h"
 #include "smproxy.h"
 
 /* This is probably nonportable.  But then so is the call to
@@ -35,6 +36,13 @@ Author:  Ralph Mor, X Consortium
 #include <libgnome/libgnome.h>
 #include <unistd.h>
 #include <netdb.h>
+#ifdef HAVE_SYS_PARAM_H
+#include <sys/param.h> /* for MAXHOSTNAMELEN */
+#endif
+
+#ifndef MAXHOSTNAMELEN
+#define MAXHOSTNAMELEN (256+1)
+#endif
 
 #if !defined (NI_MAXHOST)
 #define NI_MAXHOST MAXHOSTNAMELEN
